# nb-thumb

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

``` sh
pip install nb_thumb
```

## Quickstart

``` python
from nb_thumb.thumb import nb2thumb
```

``` python
nb2thumb('_test_nbs/geom_col.ipynb', label='two_variable_bar_plot')
```

![](index_files/figure-commonmark/cell-3-output-1.png)

## Usage

See [this page](./00_thumb.ipynb).
